<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\Api4\Action\BigBlueButton;

use Civi\Api4\Generic\Result;
use Civi\BigBlueButton\Call;

/**
 * Joins a meeting in Big Blue Button
 *
 * joins a meeting in Big Blue Button. See Big Blue Button API Documentation at
 * https://docs.bigbluebutton.org/development/api/#get-join
 *
 * @package Civi\Api4\Action\BigBlueButton
 */

class Join extends AbstractBBBAPi {

  /**
   * Returns the API call name. E.g. create or join.
   *
   * @return string
   */
  protected function getApiCallName(): string {
    return 'join';
  }

  /**
   * @return string
   */
  protected function getHttpMethod(): string {
    return 'GET';
  }

  /**
   * Returns whether to only do a dry run.
   * Useful to get the call url.
   *
   * @return bool
   */
  protected function getDryRun(): bool {
    return TRUE;
  }

  /**
   * @param \Civi\Api4\Generic\Result $result
   * @param \Civi\BigBlueButton\Call $call
   *
   * @return void
   */
  protected function convertCallToResult(Result $result, Call $call) {
    $result[0]['join_url'] = $call->getUrl();
  }

  /**
   * @var string
   * @required
   */
  protected $fullName;

  /**
   * @var string
   * @required
   */
  protected $meetingID;

  /**
   * @var string
   */
  protected $password;

  /**
   * @var string
   *   Either MODERATOR or VIEWER
   * @required
   */
  protected $role;

  /**
   * @var string
   */
  protected $createTime;

  /**
   * @var string
   */
  protected $userId;

  /**
   * @var string
   */
  protected $webVoiceConf;

  /**
   * @var string
   */
  protected $avatarURL;

  /**
   * @var string
   */
  protected $firstName;

  /**
   * @var string
   */
  protected $lastName;

  /**
   * @var string
   */
  protected $webcamBackgroundURL;

  /**
   * @var string
   */
  protected $redirect;

  /**
   * @var string
   */
  protected $errorRedirectUrl;

  /**
   * @var string
   */
  protected $logoutURL;

  /**
   * @var string
   */
  protected $guest;

  /**
   * @var string
   */
  protected $bot;

  /**
   * @var string
   */
  protected $defaultLayout;

  /**
   * @var string
   */
  protected $excludeFromDashboard;

  /**
   * @var string
   */
  protected $enforceLayout;

}
