<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
namespace Civi\BigBlueButton\ActionProvider;

use Civi\ActionProvider\Parameter\Specification;
use Civi\ActionProvider\Parameter\SpecificationBag;
use Civi\Api4\Action\BigBlueButton\AbstractBBBAPi;
use CRM_Bigbluebutton_ExtensionUtil as E;

class GetMeetingInfo extends AbstractBBBAction {

  /**
   * @return \Civi\Api4\Action\BigBlueButton\AbstractBBBAPi
   */
  protected function getApi4Class(): AbstractBBBAPi {
    return new \Civi\Api4\Action\BigBlueButton\GetMeetingInfo('BigBlueButton', 'GetMeetingInfo');
  }

  /**
   * Returns the specification of the output parameters of this action.
   *
   * This function could be overridden by child classes.
   *
   * @return SpecificationBag
   */
  public function getOutputSpecification() {
    return new SpecificationBag([
      new Specification('returncode', 'String', 'returncode'),
      new Specification('meetingName', 'String', 'meetingName'),
      new Specification('meetingID', 'String', 'meetingID'),
      new Specification('internalMeetingID', 'String', 'internalMeetingID'),
      new Specification('createTime', 'String', 'createTime'),
      new Specification('createDate', 'String', 'createDate'),
      new Specification('voiceBridge', 'String', 'voiceBridge'),
      new Specification('dialNumber', 'String', 'dialNumberc'),
      new Specification('attendeePW', 'String', 'attendeePW'),
      new Specification('moderatorPW', 'String', 'moderatorPW'),
      new Specification('running', 'Boolean', 'running'),
      new Specification('duration', 'String', 'duration'),
      new Specification('hasUserJoined', 'Boolean', 'hasUserJoined'),
      new Specification('recording', 'Boolean', 'recording'),
      new Specification('hasBeenForciblyEnded', 'Boolean', 'hasBeenForciblyEnded'),
      new Specification('startTime', 'Integer', 'startTime'),
      new Specification('endTime', 'Integer', 'endTime'),
      new Specification('participantCount', 'Integer', 'participantCount'),
      new Specification('listenerCount', 'Integer', 'listenerCount'),
      new Specification('voiceParticipantCount', 'Integer', 'voiceParticipantCount'),
      new Specification('videoCount', 'Integer', 'videoCount'),
      new Specification('maxUsers', 'Integer', 'maxUsers'),
      new Specification('moderatorCount', 'Integer', 'moderatorCount'),
      new Specification('attendees', 'String', 'attendees'),
      new Specification('metadata', 'String', 'metadata'),
      new Specification('isBreakout', 'Boolean', 'isBreakout'),
      new Specification('messageKey', 'String', 'messageKey'),
      new Specification('message', 'String', 'message'),
      new Specification('api_call_url', 'String', 'call_url'),
    ]);
  }

}
