<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\BigBlueButton;

class Call {

  /**
   * @var string
   */
  protected $url;

  /**
   * @var string
   */
  protected $method;

  /**
   * @var string
   */
  protected $response;

  /**
   * @var array
   */
  protected $parameters;

  /**
   * @var string
   */
  protected $checksum;

  public function __construct(string $url, string $method, array $parameters, string $checksum) {
    $this->url = $url;
    $this->method = $method;
    $this->parameters = $parameters;
    $this->checksum = $checksum;
  }

  public function setResponse(string $response) {
    $this->response = $response;
  }

  public function getUrl(): string {
    return $this->url;
  }

  public function getMethod(): string {
    return $this->method;
  }

  public function getResponse(): string {
    return $this->response;
  }

  public function getParameters(): array {
    return $this->parameters;
  }

  public function getChecksum(): string {
    return $this->checksum;
  }

  public function getResponsArray(): array {
    $xmlResponse = simplexml_load_string($this->response, \SimpleXMLElement::class,LIBXML_NOCDATA);
    return json_decode(json_encode($xmlResponse), TRUE);
  }

  public function setErrorMessage(string $message) {
    $this->response = '<response><returncode>FAILED</returncode><messageKey>phpError</messageKey><message>' . htmlspecialchars($message) . '</message></response>';
  }

  public function setDryRun() {
    $this->response = '<response><returncode>SUCCESS</returncode><messageKey>dryRun</messageKey><message>Dry Run Successfull. Use the call url to try this out in the browser.</message></response>';
  }

  public function isError(): bool {
    $response = $this->getResponsArray();
    if (isset($response['returncode']) && $response['returncode'] == 'FAILED') {
      return TRUE;
    }
    return FALSE;
  }

}
