# Big Blue Button

Connector for Big Blue Button. This extension setups the connection details to the Big Blue Button.

This extension contains the following **CiviCRM Api's (v4)**:

* `BigBlueButton.Create`: which creates a meeting
* `BigBlueButton.Join`: which generates a join link for an existing meeting
* `BigBlueButton.GetMeetingInfo`: which gets information about a meeting from Big Blue Button.

The extension contains the following **(Form Processor) Actions**:

_These actions can be used in the form processor, search action designer,
data processor export tasks or any other extension which uses the action provider._

* `Big Blue Button: Create Meeting`: creates a meeting
* `Big Blue Button: Get Join URL`: generates a join url for an existing meeting
* `Big Blue Button: Get Meeting Info`: returns information about an existing meeting

See here for more information about the Big Blue Button API: https://docs.bigbluebutton.org/development/api/#overview

The extension is licensed under [AGPL-3.0](LICENSE.txt).

## Configuration

Go to **Administer** > **System Settings** > **Big Blue Button** and fill in the url to your Big Blue Button and the _Secret_.

## Development Examples


**Calling the Big Blue Button API directly with php code**

```php

$connector = bigbluebutton_connector();
$params['meetingID'] ='Test123';
$params['name'] = 'Test Meeting';
// The logic is in this function. We do an HTTP POST call to the big blue button.
// We get an array back.
$returnData = $connector->post('create', $params);


```

**Calling the Big Blue Button with CiviCRM API v4**

```php



$returnData = \Civi\Api4\BigBlueButton::create(FALSE)
  ->setName('Test van Jaap')
  ->setMeetingID('TestVanJaap')
  ->execute()
  ->first();

```

### Listening to Webhooks

Webhooks are logged in the civicrm_bbb_event_log table. This way we can see back in history which events took place.
E.g. when a user joined. Are which chat messages are sent.

When a meeting is ended we also receive a webhook. Best is to listen to this webhook and then do what ever you want to do with the data.

There is a symfony event for all webhooks. They start with the name `bbb.webhook.` and they are followed by the Big Blue Button event name. 

```php

function your_ext_civicrm_container(\Symfony\Component\DependencyInjection\ContainerBuilder $container) {
  $container->findDefinition('dispatcher')
    ->addMethodCall('addListener', array('bbb.webhook.meeting-ended', '_your_ext_bbb_webhook_listener'));
}

function _your_ext_bbb_webhook_listener(Civi\BigBlueButton\WebhookEvent $webhookEvent) {
  if ($webhookEvent->event == 'meeting-ended') {
   // Then do your business logic.
  }
}

```
