<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * Bigbluebutton.Webhook API
 *
 * @param array $params
 * @return array API result descriptor
 * @see civicrm_api3_create_success
 * @see civicrm_api3_create_error
 * @throws API_Exception
 */
function civicrm_api3_bigbluebutton_Webhook($params) {
  if (empty($params['event'])) {
    throw new API_Exception('parameter event is required');
  }
  $events = $params['event'];
  if (is_string($events)) {
    $events = json_decode($events, true);
  }
  if (!is_array($events)) {
    throw new CRM_Core_Exception('Event parameter must be a JSON object.');
  }
  $event = reset($events);
  if (!is_array($event) || !isset($event['data'])) {
    throw new CRM_Core_Exception('Event parameter must be a JSON object.');
  }
  $dao = new CRM_Bigbluebutton_BAO_BbbEventLog();
  $dao->event = $event['data']['id'];
  $dao->event_data = json_encode($event['data']);
  $dao->timestamp = date('YmdHis');
  if (isset($event['data']['attributes']['meeting']['external-meeting-id'])) {
    $dao->meeting_id = $event['data']['attributes']['meeting']['external-meeting-id'];
  }
  if (isset($event['data']['attributes']['meeting']['internal-meeting-id'])) {
    $dao->internal_meeting_id = $event['data']['attributes']['meeting']['internal-meeting-id'];
  }
  $dao->save(FALSE);
  $values = [];
  CRM_Bigbluebutton_BAO_BbbEventLog::storeValues($dao, $values);
  $values['event_data'] = json_decode($values['event_data'], true);
  $webHookEvent = new \Civi\BigBlueButton\WebhookEvent($values);
  Civi::dispatcher()->dispatch('bbb.webhook.' . $values['event'], $webHookEvent);

  return civicrm_api3_create_success($values, $params, 'Bigbluebutton', 'Webhook');
}

/**
 * Bigbluebutton.Webhook API specification (optional)
 * This is used for documentation and validation.
 *
 * @param array $spec description of fields supported by this API call
 * @return void
 * @see https://docs.civicrm.org/dev/en/latest/framework/api-architecture/
 */
function _civicrm_api3_bigbluebutton_Webhook_spec(&$spec) {
  $spec['event']['api.required'] = 1;
}
