<?php

require_once 'bigbluebutton.civix.php';
// phpcs:disable
use CRM_Bigbluebutton_ExtensionUtil as E;
// phpcs:enable

function bigbluebutton_connector(): \Civi\BigBlueButton\Connector {
  return \Civi::service('bigbluebutton_connector');
}

function bigbluebutton_credentials(): \Civi\BigBlueButton\Credentials {
  return \Civi::service('bigbluebutton_credentials');
}

/**
 * Implements hook_civicrm_container()
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_container/
 */
function bigbluebutton_civicrm_container(\Symfony\Component\DependencyInjection\ContainerBuilder $container) {
  $container->addCompilerPass(new \Civi\BigBlueButton\CompilerPass());
  $container->addCompilerPass(new Civi\BigBlueButton\ActionProvider\CompilerPass(), \Symfony\Component\DependencyInjection\Compiler\PassConfig::TYPE_OPTIMIZE);
}

function bigbluebutton_civicrm_navigationMenu(&$menu) {
  _bigbluebutton_civix_insert_navigation_menu($menu, 'Administer/System Settings', [
    'label' => E::ts('Big Blue Button Settings'),
    'name' => 'bigbluebutton_settings',
    'url' => 'civicrm/admin/setting/bigbluebutton',
    'permission' => 'administer CiviCRM',
  ]);
  _bigbluebutton_civix_insert_navigation_menu($menu, 'Reports', [
    'label' => E::ts('Big Blue Button Webhook Log'),
    'name' => 'bigbluebutton_webhook_event_log',
    'url' => 'civicrm/bigbluebutton/eventlog',
    'permission' => 'administer CiviCRM',

  ]);
}

/**
 * Implements hook_civicrm_xmlMenu().
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_xmlMenu
 */
function bigbluebutton_civicrm_xmlMenu(&$files) {
  $menuXmlFiles = glob(__DIR__ . '/xml/Menu/*.xml');
  if (is_array($menuXmlFiles)) {
    foreach ($menuXmlFiles as $file) {
      $files[] = $file;
    }
  }
}

/**
 * Implements hook_civicrm_alterSettingsFolders().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_alterSettingsFolders
 */
function bigbluebutton_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
  $settingsDir = __DIR__ . DIRECTORY_SEPARATOR . 'settings';
  if (!in_array($settingsDir, $metaDataFolders) && is_dir($settingsDir)) {
    $metaDataFolders[] = $settingsDir;
  }
}

/**
 * Implements hook_civicrm_buildForm().
 *
 * @param string $formName
 * @param CRM_Core_Form $form
 */
function bigbluebutton_civicrm_buildForm($formName, $form) {
  if ($form instanceof CRM_Admin_Form_Generic && $form->getSettingPageFilter() == 'bigbluebutton') {
    CRM_Core_Region::instance('page-body')->add([
      'template' => "CRM/Bigbluebutton/linktomanagewebhooks.tpl"
    ]);
  }
}

/**
 * Implements hook_civicrm_postProcess().
 *
 * @param string $formName
 * @param CRM_Core_Form $form
 */
function bigbluebutton_civicrm_postProcess($formName, $form) {
  if ($form instanceof CRM_Admin_Form_Generic && $form->getSettingPageFilter() == 'bigbluebutton') {
    $credentials = bigbluebutton_credentials();
    if ($credentials->enableWebhook()) {
      $connector = bigbluebutton_connector();
      if ($connector->setWebhookUrl()) {
        \CRM_Core_Session::setStatus(E::ts('Successfully set webhook'), E::ts('Big Blue Button'), 'success');
      }
      else {
        \CRM_Core_Session::setStatus(E::ts('Could not set webhook'), E::ts('Big Blue Button'), 'error');
      }
    }
  }
}


/**
 * Implements hook_civicrm_permission().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_permission/
 */
function bigbluebutton_civicrm_permission(array &$permissions) {
  $permissions['access Big Blue Button Webhook'] = [
    'label' => E::ts('Big Blue Button: access webhook'),
    'description' => E::ts('Gives this to anonymous users to allow processing of webhooks'),
  ];
}

/**
 * Implements hook_civicrm_alterAPIPermissionsc().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_alterAPIPermissions/
 */
function bigbluebutton_civicrm_alterAPIPermissions($entity, $action, &$params, &$permissions)
{
  $permissions['bigbluebutton']['webhook'] = array('access Big Blue Button Webhook');
}

/**
 * Implements hook_civicrm_entityTypes().
 *
 * Declare entity types provided by this module.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_entityTypes
 */
function bigbluebutton_civicrm_entityTypes(&$entityTypes) {
  $entityTypes = array_merge($entityTypes, [
    'CRM_Bigbluebutton_DAO_BbbEventLog' =>   [
      'name' => 'BbbEventLog',
      'class' => 'CRM_Bigbluebutton_DAO_BbbEventLog',
      'table' => 'civicrm_bbb_event_log',
    ],
  ]);
}

/**
 * Implements hook_civicrm_config().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config/
 */
function bigbluebutton_civicrm_config(&$config): void {
  _bigbluebutton_civix_civicrm_config($config);
  static $configured = FALSE;
  if ($configured) {
    return;
  }
  $configured = TRUE;

  // Fix for CiviCRM version 5.40
  $template = CRM_Core_Smarty::singleton();
  $extRoot = __DIR__ . DIRECTORY_SEPARATOR;
  $extDir = $extRoot . 'templates';
  $template->addTemplateDir($extDir);
}

/**
 * Implementation of hook_civicrm_managed
 *
 * Generate a list of entities to create/deactivate/delete when this module
 * is installed, disabled, uninstalled.
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_managed
 */
function bigbluebutton_civicrm_managed(&$entities) {
  $mgdFiles = CRM_Utils_File::findFiles(__DIR__, '*.mgd.php');
  sort($mgdFiles);
  foreach ($mgdFiles as $file) {
    $es = include $file;
    foreach ($es as $e) {
      if (empty($e['module'])) {
        $e['module'] = E::LONG_NAME;
      }
      if (empty($e['params']['version'])) {
        $e['params']['version'] = '3';
      }
      $entities[] = $e;
    }
  }
}

/**
 * Implements hook_civicrm_install().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
 */
function bigbluebutton_civicrm_install(): void {
  _bigbluebutton_civix_civicrm_install();
}

/**
 * Implements hook_civicrm_enable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
 */
function bigbluebutton_civicrm_enable(): void {
  _bigbluebutton_civix_civicrm_enable();
}
